# **********************************************************************
# Copyright 2014 VMware, Inc.  All rights reserved. VMware Confidential.
# **********************************************************************
# $Id$
# $DateTime$
# $Change$
# $Author$
# **********************************************************************


__all__ = ["CliMessageDescriptor"]


import nsx_logging
import os
import yaml

from lib.json_schema import JsonSchema
from cli.descriptors.descriptor import Descriptor
from cli.descriptors.descriptor import SCHEMA_REGISTRY


lg = nsx_logging.getLogger("cli.descriptors.cli_message_descriptor")


ERROR_MESSAGE_SCHEMA_FILE = os.path.join(os.path.dirname(__file__),
                                         'cli_message_descriptor.yml')
ERROR_MESSAGE_TYPES = dict((r.id, r)
                         for r in yaml.load(open(ERROR_MESSAGE_SCHEMA_FILE), Loader=yaml.Loader))
for key in list(ERROR_MESSAGE_TYPES.keys()):
    if key not in SCHEMA_REGISTRY:
        JsonSchema(ERROR_MESSAGE_TYPES[key].raw_schema,
                   schema_registry=SCHEMA_REGISTRY, type_path=[key],
                   strict=True)


class CliMessageDescriptor(Descriptor):
    """Descriptor specification of a CLI message.

    Messages are used to convey status or errors, etc.  Any CLI command
    that needs to show a message should do so via a CliMessageDescriptor
    and calling either a render_util or error_util instead of outputing
    directly to stdout.
    """
    yaml_tag = '!CliMessage'

    def __init__(self, id, schema_spec):
        super(CliMessageDescriptor, self).__init__(id, schema_spec)
        self._raw_schema = schema_spec
        self._message = schema_spec["message"]
        self._nsx_feature = schema_spec.get("nsx_feature")

    @property
    def raw_schema(self):
        return self._raw_schema

    @property
    def message(self):
        return self._message
