# ***************************************************************************
# Copyright 2019-2020 VMware, Inc.  All rights reserved. VMware Confidential.
# ***************************************************************************
# $Id$
# $DateTime$
# $Change$
# $Author$
# ***************************************************************************
"""This utility script will read receivers.json via stdin and then
update /etc/vmware/snmp/snmp.xml accordingly"""

import json
import sys
import subprocess
sys.path.append("/opt/vmware/nsx-common/python")
import nsx_logging

def read_receivers_json():
    receivers_in_json = json.load(sys.stdin)
    v2receiver_list = []
    v3receiver_list = []
    for receiver in receivers_in_json["receivers"]:
        if "security_level" not in receiver:
            receiver["security_level"] = 'NONE'
        if receiver["receiver_type"] == 'SNMPV2Receiver':
            receiver_str = '%s@%d/%s/%s/trap' %(
                receiver["server"], receiver["port"], receiver["community_string"],
                to_standard_security_level(receiver["security_level"]))
            v2receiver_list.append(receiver_str)
        elif receiver["receiver_type"] == 'SNMPV3Receiver':
            receiver_str = '%s@%d/%s/%s/trap' %(
                receiver["server"], receiver["port"], receiver["user"],
                to_standard_security_level(receiver["security_level"]))
            v3receiver_list.append(receiver_str)
    return v2receiver_list, v3receiver_list

def to_standard_security_level(security_level):
    if security_level == '' or security_level == 'NONE':
        return 'none'  #noAuthNoPriv
    elif security_level == 'AUTH':
        return 'auth'  #authNoPriv
    elif security_level == 'PRIV':
        return 'priv'  #authPriv
    else:
        lg.error('Invalid security level %s', security_level)
        return 'none'

def update_target_in_snmpxml(receiver_list, version_flag):
    receiver_str = ','.join(receiver_list)
    cmd_option = "-t" if version_flag == 'V2' else "-i"
    po = subprocess.Popen([sys.executable, "/opt/vmware/bin/vicfg-snmp",
        cmd_option, receiver_str],
        stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    out, err = [p.decode() for p in po.communicate()]
    if po.returncode != 0:
        lg.info(
            "Error updating %s target in snmp xml, rc: %s, out: %s, err: %s",
            version_flag, po.returncode, out, err)
        return False
    return True

if __name__ == "__main__":
    nsx_logging.basicConfig(syslog=True, subcomp="trigger_snmpxml_update")
    lg = nsx_logging.getLogger()
    lg.setLevel(nsx_logging.INFO)
    _EXIT_CODE = 0
    _V2RECEIVERS, _V3RECEIVERS = read_receivers_json()
    if not update_target_in_snmpxml(_V2RECEIVERS, "V2"):
        _EXIT_CODE = 1
    if not update_target_in_snmpxml(_V3RECEIVERS, "V3"):
        _EXIT_CODE = 1
    sys.exit(_EXIT_CODE)
