# Copyright (C) 2020-2021 VMware, Inc. All rights reserved.
# -- VMware Confidential
from sha import config
from sha.core.channel.hub import Hub
from sha.core.channel.provider import MpaProvider, AlarmProvider, WfProvider, FiledumpProvider

from sha.core.channel.provider.filedump_provider import trace_span_dump_callback, trace_span_init_callback

from sha.constants import MPA_HUB, ALARM_HUB, WAVEFRONT_HUB, TRACEDUMP_HUB, TSDB_HUB

class HubHolder:
    _logger = config.get_logger(__name__)
    _mpa_hub = Hub(MpaProvider(), MPA_HUB)
    _alarm_hub = Hub(AlarmProvider(), ALARM_HUB)
    _wf_hub = Hub(WfProvider(), WAVEFRONT_HUB)
    _tracedump_hub = Hub(FiledumpProvider(config.WORKFLOW_TRACE_FILENAME, init_callback = trace_span_init_callback,
                                          dump_callback = trace_span_dump_callback, max_bytes = config.WORKFLOW_TRACE_FILE_MAX_BYTES,
                                          backup_count = config.WORKFLOW_TRACE_FILE_BACKUP_COUNT),
                         TRACEDUMP_HUB, queue_size = config.WORKFLOW_TRACE_FILEDUMP_QUEUE_SIZE)
    _hubs= {
        MPA_HUB: _mpa_hub,
        ALARM_HUB: _alarm_hub,
        WAVEFRONT_HUB: _wf_hub,
        TRACEDUMP_HUB: _tracedump_hub,
    }

    # support TSDB hub on linux
    if config.SYSTEM == config.PLATFORM_LINUX:
        from sha.core.channel.provider import TsdbProvider
        _tsdb_hub = Hub(TsdbProvider(), TSDB_HUB)
        _hubs[TSDB_HUB] = _tsdb_hub

    @classmethod
    def start_hubs(cls):
        for key, value in cls._hubs.items():
            cls._logger.info("starting {}".format(key))
            value.start()

    @classmethod
    def stop_hubs(cls):
        for key, value in cls._hubs.items():
            cls._logger.info("stopping {}".format(key))
            value.stop()

    @classmethod
    def wait_hubs_stop(cls):
        for key, value in cls._hubs.items():
            value.join()

    @classmethod
    def hubs(cls):
        return cls._hubs
