# Copyright (C) 2021 VMware, Inc. All rights reserved.
# -- VMware Confidential
import importlib

from sha.config import DIST_ESX, DIST_KVM, DIST_BMS, DIST_EDGE, DIST_PUBLIC_CLOUD_GATEWAY, \
    PLATFORM_ESX, PLATFORM_LINUX, PLATFORM_WINDOWS, SYSTEM, ENABLED_RMDY_CMD, NODE_TYPE

from sha.preconfig import get_sub_logger

_logger = get_sub_logger(__name__, s2comp="rmdy-cmd-lib")


class RmdyCmdLib:
    """
    Remedy cmd library, holding all available cmd and provide common facility for remedy cmd
    """

    cmd_mapping = {}

    @classmethod
    def get_cmd(cls, tag_cmd):
        """
        Get loaded cmd by tag
        """
        if tag_cmd not in cls.cmd_mapping:
            raise Exception("cmd: [{}] is disallowed on node: [{}], platform:[{}]".format(tag_cmd, NODE_TYPE, SYSTEM))
        return cls.cmd_mapping[tag_cmd]

    @classmethod
    def check_success(cls, result, tag_cmd):
        """
        Check whether cmd is executed successfully.
        """
        return cls.cmd_mapping[tag_cmd].is_success(result)

    @classmethod
    def load_cmd(cls):
        """
        Load all available cmd on current node/platform
        """
        for class_name, module_name in ENABLED_RMDY_CMD.items():
            _logger.info("loaded cmd: {}".format(class_name))
            cmd_module = importlib.import_module('sha.contrib.rmdy_cmd.{}'.format(module_name))
            rmdy_cmd = getattr(cmd_module, class_name)()
            cls.cmd_mapping[rmdy_cmd.get_tag_cmd()] = rmdy_cmd



